/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.weekday.check;

import java.util.Calendar;

import org.tinygroup.weekday.DateChecker;
import org.tinygroup.weekday.PureDate;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * 普通工作日计算方法,1-5工作，6日休息
 * @author luoguo
 *
 */
@XStreamAlias("default-date-checker")
public class DefaultDateChecker implements DateChecker {
	/**
	 * 只要是周一到周五就是工作日
	 */
	public boolean isWeekday(PureDate pureDate) {
		Calendar calendar = Calendar.getInstance();
		calendar.setFirstDayOfWeek(Calendar.MONDAY);
		calendar.set(pureDate.getYear(), pureDate.getMonth() - 1,
				pureDate.getDay());
		int day = calendar.get(Calendar.DAY_OF_WEEK);
		return day >= Calendar.MONDAY && day <= Calendar.FRIDAY;
	}

	public boolean isSuitableDate(PureDate pureDate) {
		return true;
	}

}
